@@ -4,12 +4,10 @@
 modname = 'registration'
 distname = 'cubicweb-registration'
 
-numversion = (0, 3, 1)
+numversion = (0, 3, 2)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
-copyright = '''Copyright (c) 2009-2010 LOGILAB S.A. (Paris, FRANCE).
-http://www.logilab.fr -- mailto:contact@logilab.fr'''
 
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
@@ -17,11 +15,11 @@ author_email = 'contact@logilab.fr'
 web = 'http://www.cubicweb.org/project/%s' % distname
 
 short_desc = 'public registration component for the CubicWeb framework'
-long_desc = """This CubicWeb component provides a public registration feature (users
-can register and create an account without the need for admin
-intervention).
+long_desc = """\
+This cube provides a public registration feature (anonymous users can register
+and create an account without the need for admin intervention).
 
-CubicWeb is a semantic web application framework, see http://www.cubicweb.org
+It is non-obstrusive and easy to plug.
 """
 
 classifiers = [
@@ -32,7 +30,7 @@ classifiers = [
     ]
 
 __depends_cubes__ = {}
-__depends__ = {'cubicweb': '>= 3.7.2',
+__depends__ = {'cubicweb': '>= 3.7.4',
                'python-crypto': None,
                'PIL': None,
                }
